@@ -415,6 +415,11 @@ pub(crate) fn parse_nl_msg_to_iface(
             vlan_info.base_iface = format!("{}", base_iface_index);
         }
     }
+    if let Some(ref mut ib_info) = iface_state.ipoib {
+        if let Some(base_iface_index) = link {
+            ib_info.base_iface = Some(format!("{}", base_iface_index));
+        }
+    }
     if let Some(iface_index) = link {
         match iface_state.iface_type {
             IfaceType::Veth => {
